@@ -82,6 +82,8 @@
 #include <unistd.h>
 #include <sys/param.h>
 #include <sys/types.h>
+#else
+#include <io.h>
 #endif
 
 // Default advertisement expiration time used if the exp parameter to UpnpSendAdvertisement() is <=0
@@ -1888,7 +1890,7 @@ int UpnpDownloadUrlItem(const std::string& url,
 }
 
 /* Get callback function ptr from a handle. */
-Upnp_FunPtr GetCallBackFn(UpnpClient_Handle Hnd)
+[[maybe_unused]] static Upnp_FunPtr GetCallBackFn(UpnpClient_Handle Hnd)
 {
     return (static_cast<struct Handle_Info *>(HandleTable[Hnd]))->Callback;
 }
@@ -2212,7 +2214,7 @@ int UpnpSetMaxContentLength(size_t contentLength)
     return UPNP_E_SUCCESS;
 }
 
-int UpnpSetEventQueueLimits(int maxLen, int maxAge)
+[[maybe_unused]] static int UpnpSetEventQueueLimits(int maxLen, int maxAge)
 {
     g_UpnpSdkEQMaxLen = maxLen;
     g_UpnpSdkEQMaxAge = maxAge;
