@@ -305,7 +305,6 @@ std::string IPAddr::straddr(bool setscope, bool forurl) const
         s += std::string(forurl ? "%25" : "%") + scopebuf;
         return s;
     }
-    break;
     }
     return buf;
 }
@@ -597,7 +596,7 @@ Interfaces::Internal::Internal()
 
 #else /* _WIN32 ->*/
 
-bool wchartoutf8(const wchar_t *in, std::string& out, size_t wlen)
+static bool wchartoutf8(const wchar_t* in, std::string& out, size_t wlen)
 {
     out.clear();
     if (nullptr == in) {
